@@ -38,11 +38,11 @@ class PackageChecker(Checker[PackageModel]):
 
   @check('license')
   def _check_license(self, package: PackageModel) -> Iterable[CheckResult]:
-    if not package.license:
-      yield CheckResult(CheckStatus.WARNING, 'not specified')
-
-    elif package.license and not package.get_license_file():
-      yield CheckResult(CheckStatus.WARNING, 'No LICENSE file found.')
+    if not package.get_license_file(True):
+      if not package.license:
+        yield CheckResult(CheckStatus.WARNING, 'not specified')
+      else:
+        yield CheckResult(CheckStatus.WARNING, 'No LICENSE file')
 
     monorepo = package.project.monorepo
     if package.license and monorepo and monorepo.license \
@@ -62,12 +62,14 @@ class PackageChecker(Checker[PackageModel]):
 
   @check('package-url')
   def _check_author(self, package: PackageModel) -> Iterable[CheckResult]:
-    if not package.url:
+    if not package.get_url():
       yield CheckResult(CheckStatus.WARNING, 'missing')
+    else:
+      print(package.get_url())
 
   @check('package-author')
   def _check_consistent_author(self, package: PackageModel) -> Iterable[CheckResult]:
-    if not package.author:
+    if not package.get_author():
       yield CheckResult(CheckStatus.ERROR, 'missing')
     metadata = package.get_python_package_metadata()
     try:
@@ -75,11 +77,11 @@ class PackageChecker(Checker[PackageModel]):
     except PackageError as exc:
       yield CheckResult(CheckStatus.ERROR, str(exc))
       return
-    if package.author and author != str(package.author):
+    if package.get_author() and author != str(package.get_author()):
       yield CheckResult(
         CheckStatus.ERROR,
         'Inconsistent package author (package.yaml: {!r} != {}: {!r})'.format(
-          str(package.author), metadata.filename, author))
+          str(package.get_author()), metadata.filename, author))
 
   @check('package-version')
   def _check_consistent_version(self, package: PackageModel) -> Iterable[CheckResult]:
@@ -117,6 +119,17 @@ class PackageChecker(Checker[PackageModel]):
           'file "py.typed" exists but $.typed is not set')
     yield SkipCheck()
 
+  @check('namespace files')
+  def _check_naemspace_files(self, package: PackageModel) -> Iterable[CheckResult]:
+    namespaces = package.get_modulename().split('.')[:-1]
+    namespaces = [os.sep.join(namespaces[:i+1]) for i in range(len(namespaces))]
+
+    for namespace in namespaces:
+      namespace_file = os.path.join(package.get_directory(), package.source_directory, namespace, '__init__.py')
+      if not os.path.exists(namespace_file):
+        yield CheckResult(CheckStatus.WARNING,
+          f'namespace file "{namespace + os.sep}__init__.py" does not exist')
+
   @check('up to date')
   def _check_up_to_date(self, package: PackageModel) -> Iterable[CheckResult]:
     """
