@@ -23,7 +23,7 @@ import os
 import shlex
 import subprocess as sp
 import sys
-from typing import List, Optional, Set, Tuple
+from typing import cast, List, Optional, Set, Tuple
 
 import click
 from nr.stream import concat
@@ -35,11 +35,12 @@ from . import pkg
 from .. import project
 
 
-def collect_requirements(
+def collect_requirement_args(
   package: bool,
+  develop: bool,
   inter_deps: bool,
   extra: Optional[Set[str]],
-) -> RequirementsList:
+) -> List[str]:
   reqs = RequirementsList()
 
   # Pip does not understand "test" as an extra and does not have an option to
@@ -54,6 +55,7 @@ def collect_requirements(
     # TODO(NiklasRosenstein): get_inter_dependencies_for() does not currently differentiate
     #   between normal, test and extra requirements.
     project_packages = {p.name: p for p in project.packages}
+    insert_index = 0
     for ref in project.monorepo.get_inter_dependencies_for(package):
       dep = project_packages[ref.package_name]
       if not ref.version_selector.matches(dep.version):
@@ -61,34 +63,30 @@ def collect_requirements(
               '{} does not match the present version {}'
               .format(dep.name, ref.version_selector, dep.version), file=sys.stderr)
       else:
-        reqs.insert(0, VendoredRequirement(VendoredRequirement.Type.Path, dep.get_directory()))
+        reqs.insert(insert_index, VendoredRequirement(VendoredRequirement.Type.Path, dep.get_directory()))
+        insert_index += 1
 
-  return reqs
+  return reqs.get_pip_args(package.get_directory(), develop)
 
 
 def run_install(
   pip: Optional[str],
-  reqs: List[Tuple[str, RequirementsList]],
+  args: List[str],
   develop: bool,
   upgrade: bool,
   quiet: bool,
   dry: bool,
-  pip_args: Optional[str],
 ) -> None:
 
   pip_bin = shlex.split(os.getenv('PIP', pip or 'python -m pip'))
-  command = pip_bin + ['install']
-  for directory, req in reqs:
-    command += req.to_pip_args(directory, develop)
+  command = pip_bin + ['install'] + args
   if upgrade:
     command.append('--upgrade')
   if quiet:
     command.append('--quiet')
-  command += shlex.split(pip_args) if pip_args else []
 
-  command_str = ' '.join(map(shlex.quote, command))
   if dry:
-    print(command_str)
+    print(' '.join(map(shlex.quote, command)))
   else:
     sys.exit(sp.call(command))
 
@@ -110,7 +108,8 @@ def split_extras(extras: str) -> Set[str]:
 @click.option('--pip', help='Override the command to run Pip. Defaults to "python -m pip" or the PIP variable.')
 @click.option('--pip-args', help='Additional arguments to pass to Pip.')
 @click.option('--dry', is_flag=True, help='Print the Pip command to stdout instead of running it.')
-def install(develop, inter_deps, extra, upgrade, quiet, pip, pip_args, dry):
+@click.option('--pipx', is_flag=True, help='Install using Pipx.')
+def install(develop, inter_deps, extra, upgrade, quiet, pip, pip_args, dry, pipx):
   """
   Install the package using `python -m pip`. If the package is part of a mono repository,
   inter-dependencies will be installed from the mono repsitory rather than from PyPI.
@@ -118,6 +117,15 @@ def install(develop, inter_deps, extra, upgrade, quiet, pip, pip_args, dry):
   The command used to invoke Pip can be overwritten using the `PIP` environment variable.
   """
 
-  package = project.load_or_exit(expect=PackageModel)
-  reqs = collect_requirements(package, inter_deps, extra)
-  run_install(pip, [(package.get_directory(), reqs)], develop, upgrade, quiet, dry, pip_args)
+  if not pip and pipx:
+    pip = 'pipx'
+
+  package = cast(PackageModel, project.load_or_exit(expect=PackageModel))
+  args = collect_requirement_args(package, develop, inter_deps, extra)
+  if pipx:
+    args += ['--pip-args', ' '.join(map(shlex.quote, package.install.get_pip_args()))]
+  else:
+    args += package.install.get_pip_args()
+  if pip_args:
+    args += shlex.split(pip_args)
+  run_install(pip, args, develop, upgrade, quiet, dry)
